Method: SwitchTower::Configuration#require
- Defined in:
- lib/switchtower/configuration.rb
#require(*args) ⇒ Object
Require another file. This is identical to the standard require method, with the exception that it sets the reciever as the “current” configuration so that third-party task bundles can include themselves relative to that configuration.
201 202 203 204 205 206 207 |
# File 'lib/switchtower/configuration.rb', line 201 def require(*args) #:nodoc: original, SwitchTower.configuration = SwitchTower.configuration, self super ensure # restore the original, so that require's can be nested SwitchTower.configuration = original end |